==> SVR-0.4.tar.gz: SVR-0.4/setup.py <==
from distutils.core import setup
setup(
  name = 'SVR',         # How you named your package folder (MyLib)
  packages = ['SVR'],   # Chose the same as "name"
  version = '0.4',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'will retive latest version of softwatre',   # Give a short description about your library
  author = 'yuvaraj,naveen',                   # Type in your name
  author_email = 'navicpy@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/yuvarajicon/SVR',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/YuvarajIcon/SVR.git',    # I explain this later on
  keywords = ['VERSION', 'RETRIVER', 'UPDATE','LATEST','NEW','SOFTWARE','WEBPAGE','WEBCRWALING'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          
          
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> SVR-0.5.tar.gz: SVR-0.5/setup.py <==
from distutils.core import setup
setup(
  name = 'SVR',         # How you named your package folder (MyLib)
  packages = ['SVR'],   # Chose the same as "name"
  version = '0.5',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Used to retrieve the latest version of a software and will return it as a string',   # Give a short description about your library
  author = 'Yuvaraj Icon, Naveen',                   # Type in your name
  author_email = 'navicpy@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/yuvarajicon/SVR',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/YuvarajIcon/SVR.git',    # I explain this later on
  keywords = ['VERSION', 'RETRIVER', 'UPDATE','LATEST','NEW','SOFTWARE','WEBPAGE','WEBCRWALING'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
